@@ -18,16 +18,15 @@ struct table {
 #define BILLION 1000000000
 #define HISTSIZE 2500
 #define NSPERBUCKET 1
-#define MAXHISTLINES 10
+#define NSPERBUCKET2 250
+#define MAXHISTLINES 15
 
 struct table clocks [] = {
 	{CLOCK_REALTIME, "CLOCK_REALTIME"},
 #ifdef CLOCK_REALTIME_COARSE
 	{CLOCK_REALTIME_COARSE, "CLOCK_REALTIME_COARSE"},
 #endif
-#ifdef CLOCK_MONOTONIC
 	{CLOCK_MONOTONIC, "CLOCK_MONOTONIC"},
-#endif
 #ifdef CLOCK_MONOTONIC_RAW
 	{CLOCK_MONOTONIC_RAW, "CLOCK_MONOTONIC_RAW"},
 #endif
@@ -45,17 +44,17 @@ static int getpid_average(void) {
         struct timespec start, stop;
         uint64_t sec, nanos;
 
-        err = clock_gettime(CLOCK_REALTIME, &start);
+        err = clock_gettime(CLOCK_MONOTONIC, &start);
         if (-1 == err) {
-                printf("clock_gettime(CLOCK_REALTIME) didn't work, err %d\n", errno);
+                printf("clock_gettime(CLOCK_MONOTONIC) didn't work, err %d\n", errno);
                 return -1;
         }
 
-        clock_gettime(CLOCK_REALTIME, &start);
+        clock_gettime(CLOCK_MONOTONIC, &start);
         for (int i = 0; i < BATCHSIZE; i++) {
                 getpid();
         }
-        clock_gettime(CLOCK_REALTIME, &stop);
+        clock_gettime(CLOCK_MONOTONIC, &stop);
 
         /* Beware of overflowing 32 bits. */
         sec = (stop.tv_sec-start.tv_sec);
@@ -71,17 +70,17 @@ static int gettimeofday_average(void) {
         uint64_t sec, nanos;
 	struct timeval now;
 
-        err = clock_gettime(CLOCK_REALTIME, &start);
+        err = clock_gettime(CLOCK_MONOTONIC, &start);
         if (-1 == err) {
-                printf("clock_gettime(CLOCK_REALTIME) didn't work, err %d\n", errno);
+                printf("clock_gettime(CLOCK_MONOTONIC) didn't work, err %d\n", errno);
                 return -1;
         }
 
-        clock_gettime(CLOCK_REALTIME, &start);
+        clock_gettime(CLOCK_MONOTONIC, &start);
         for (int i = 0; i < BATCHSIZE; i++) {
                 gettimeofday(&now, NULL);
         }
-        clock_gettime(CLOCK_REALTIME, &stop);
+        clock_gettime(CLOCK_MONOTONIC, &stop);
 
         /* Beware of overflowing 32 bits. */
         sec = (stop.tv_sec-start.tv_sec);
@@ -118,11 +117,11 @@ static int do_average(int type, const char* name) {
 		return -1;
 	}
 
-	clock_gettime(CLOCK_REALTIME, &start);
+	clock_gettime(CLOCK_MONOTONIC, &start);
 	for (int i = 0; i < BATCHSIZE; i++) {
 		clock_gettime(type, &stop);
 	}
-	clock_gettime(CLOCK_REALTIME, &stop);
+	clock_gettime(CLOCK_MONOTONIC, &stop);
 
 	/* Beware of overflowing 32 bits. */
 	sec = (stop.tv_sec-start.tv_sec);
@@ -131,12 +130,10 @@ static int do_average(int type, const char* name) {
 
 }
 
-static int do_fastest(int type, const char* name) {
+static int do_fastest(int type) {
 	struct timespec start, stop;
 	uint64_t sec, nanos, fastest;
 
-	(void)name;  /* Squash unused warnings */
-
 	dups = 0;
 	fastest = 999999999;
 	for (int i = 0; i < BATCHSIZE; i++) {
@@ -150,28 +147,53 @@ static int do_fastest(int type, const char* name) {
 			dups++;
 			continue;
 		}
-		if (nanos < fastest) { fastest = nanos;
-		}
+		if (nanos < fastest) fastest = nanos;
 	}
 
 	return fastest;
 }
-
-static int do_hist(int type, int fastest) {
-	int nsPerBucket = NSPERBUCKET;
-	int i;
-	int delta, lines, toobig, hits, miss;
+static int do_slowest(int type) {
 	struct timespec start, stop;
-	int64_t sec, nanos;
-	unsigned int hist[HISTSIZE];
-	int faster = 0;
+	uint64_t sec, nanos, slowest;
 
 	dups = 0;
-	toobig = 0;
-	for (i = 0; i < HISTSIZE; i++) {
-		hist[i] = 0;
+	slowest = 0;
+	for (int i = 0; i < BATCHSIZE; i++) {
+		clock_gettime(type, &start);  /* warm up caches */
+		clock_gettime(type, &start);
+		clock_gettime(type, &stop);
+		sec = (stop.tv_sec-start.tv_sec);
+		nanos = sec*BILLION + (stop.tv_nsec-start.tv_nsec);
+		if (0 == nanos) {
+			/* I've seen this on Pi 1. */
+			dups++;
+			continue;
+		}
+		if (nanos > slowest) slowest = nanos;
 	}
 
+	return slowest;
+}
+
+/* The second hist shows the tail. */
+static void do_hist(int type) {
+	int nsPerBucket = NSPERBUCKET;
+	int nsPerBucket2 = NSPERBUCKET2;
+	int i;
+	int index, lines, toobig, hits;
+	int last = 0;
+	struct timespec start, stop;
+	int64_t sec, nanos, slowest;
+	unsigned int hist[HISTSIZE];
+	unsigned int hist2[HISTSIZE];
+
+	dups = 0;
+	for (i = 0; i < HISTSIZE; i++) {
+		hist[i] = 0;
+		hist2[i] = 0;
+	}
+
+	slowest = 0;
 	for (i = 0; i < BATCHSIZE; i++) {
 		clock_gettime(type, &start);  /* warm up cache */
 		clock_gettime(type, &stop);
@@ -187,33 +209,29 @@ static int do_hist(int type, int fastest) {
 			continue;
 		}
 		if (0 == nanos) {
-			/* I've seen this on Pi 1. */
+			/* This happens on Pi 1. */
 			dups++;
 			continue;
 		}
-		delta = (nanos-fastest) / nsPerBucket;
-		if (0 > delta) {
-			/* fastest wasn't fast enough */
-			if (0 == faster) {
-				faster = delta;
-			}
-			if (faster > delta) {
-				faster = delta;
-			}
-			continue;
+		index = nanos / nsPerBucket;
+		if (index < HISTSIZE) {
+			hist[index]++;
 		}
-		if (delta < HISTSIZE) {
-			hist[delta]++;
-		} else {
-			toobig++;
+		index = nanos / nsPerBucket2;
+		if (index < HISTSIZE) {
+			hist2[index]++;
 		}
+		if (slowest < nanos) slowest = nanos;
 	}
-	if (faster) { return faster;
+	if (dups) {
+		printf("%d samples were duplicated.\n", dups);
 	}
+
 	printf("\n");
 	printf("Histogram: CLOCK_REALTIME, %d ns per bucket, %d samples.\n",
 	       nsPerBucket, BATCHSIZE);
 	printf("        ns      hits\n");
+	toobig = 0;
 	lines = 0;
 	hits = 0;
 	for (i=0; i<HISTSIZE; i++) {
@@ -221,28 +239,45 @@ static int do_hist(int type, int fastest) {
 			break;  /* Avoid clutter of printing long tail */
 		}
 		if (hist[i]) {
-			printf("%10d  %8u\n", i*nsPerBucket+fastest, hist[i]);
+			last = i*nsPerBucket;
+			printf("%10d  %8u\n", i*nsPerBucket, hist[i]);
 			lines++;
 			hits += hist[i];
 		}
 	}
-	miss = i-1;
-	for (  ; i<HISTSIZE; i++) {
-		toobig += hist[i];
+	toobig = BATCHSIZE-hits;
+	if (toobig) { printf("%d samples were bigger than %d.\n",
+			     toobig, last);
 	}
 
-	if (dups) {
-		printf("%d samples were duplicated.\n", dups);
+	printf("\n");
+	printf("Histogram: CLOCK_REALTIME, %d ns per bucket, %d samples.\n",
+	       nsPerBucket2, BATCHSIZE);
+	printf("        ns      hits\n");
+	lines = 0;
+	hits = 0;
+	for (i=0; i<HISTSIZE; i++) {
+		if ((MAXHISTLINES <= lines) && (0.98*BATCHSIZE < hits)) {
+			break;  /* Avoid clutter of printing long tail */
+		}
+		if (hist2[i]) {
+			last = i*nsPerBucket2;
+			printf("%10d  %8u\n", i*nsPerBucket2, hist2[i]);
+			lines++;
+			hits += hist2[i];
+		}
 	}
-	if (toobig) { printf("%d samples were bigger than %d.\n",
-			     toobig, miss*nsPerBucket+fastest);
+	toobig = BATCHSIZE-hits;
+	if (toobig) {
+		printf("%d samples were bigger than %d.\n", toobig, last);
+		printf("Slowest was %ld.\n", (long)slowest);
 	}
-	return faster;
 }
 
 
 int main(int argc, char *argv[]) {
 	int res, average, fastest;
+	int slowestest = 0;
 
 	(void)argc;  /* Squash unused warnings */
 	(void)argv;
@@ -257,7 +292,7 @@ int main(int argc, char *argv[]) {
 	for (int i=0; (NULL != clocks[i].name); i++) {
 		res = do_res(clocks[i].type, clocks[i].name);
 		average = do_average(clocks[i].type, clocks[i].name);
-		fastest = do_fastest(clocks[i].type, clocks[i].name);
+		fastest = do_fastest(clocks[i].type);
 		printf("%9d %5d %8d", res, average, fastest);
 		if (0.9*BATCHSIZE < dups) {
 			/* Hack: negative to show good if close to all are bad */
@@ -272,17 +307,25 @@ int main(int argc, char *argv[]) {
 	}
 
 	if (1) {
-		int faster;
-		fastest = do_fastest(CLOCK_REALTIME, "CLOCK_REALTIME");
-		while (1) {
-			faster = do_hist(CLOCK_REALTIME, fastest);
-			if (0 == faster) { break;
-			}
-			printf("Found faster: %d => %d\n", fastest, faster);
-			fastest = faster;
-		}
+		fastest = do_fastest(CLOCK_REALTIME);
+		do_hist(CLOCK_REALTIME);
 	}
 
+	
+	printf("\nSlowest from each batch of %d...\n", BATCHSIZE);
+        for (int i=0; i<50; i++) {
+		int slowest;
+		slowest = do_slowest(CLOCK_REALTIME);
+		printf(" %6ld", (long)slowest);
+		if ((i%10)==9) printf("\n");
+		if (dups) {
+		  printf("  %d samples were duplicated.\n", dups);
+		}
+		if (slowest > slowestest) slowestest = slowest;
+
+	}
+	printf("Slowest was %ld\n", (long)slowestest);
+
 	return 0;
 
 }
