@@ -70,6 +70,16 @@ struct ctl_var {
 #define DEF		0x20
 #define	PADDING		0x40
 #define	EOV		0x80
+#define ToMS		0x100
+#define ToPPM		0x200
+#define DBL6		0x400
+#define N_LEAP          0x800   /* Need to read Leap Second info */
+#define N_CLOCK         0x1000  /* Need to read kernel Clock info */
+
+/* Conversions for ntp_adjtime's timex */
+#define KNUToMS         0x10000  /* nano vs old micro */
+#define K_16            0x20000  /* 16 bit scaling */
+#define KUToMS          0x40000  /* always micro */
 
 #define	RO	(CAN_READ)
 #define	RW	(CAN_READ|CAN_WRITE)
@@ -108,7 +118,10 @@ extern  uint64_t sent_count(void);
 extern  uint64_t notsent_count(void);
 extern  uint64_t handler_calls_count(void);
 extern  uint64_t handler_pkts_count(void);
-extern  uptime_t counter_reset_time(void);
+#ifdef REFCLOCK
+extern  uint64_t handler_refrds_count(void);
+#endif
+extern  uptime_t io_timereset;
 
 /* ntp_loopfilter.c */
 extern	void	init_loopfilter(void);
@@ -163,6 +176,33 @@ extern	int	sys_orphan;
 extern	double	sys_mindist;
 extern	double	sys_maxdisp;
 
+#define stat_sys_form(member)\
+extern uint64_t stat_##member(void);\
+extern uint64_t stat_total_##member(void)
+stat_sys_form(received);
+stat_sys_form(processed);
+stat_sys_form(restricted);
+stat_sys_form(newversion);
+stat_sys_form(oldversion);
+stat_sys_form(version1);
+stat_sys_form(version1client);
+stat_sys_form(version1zero);
+stat_sys_form(version1symm);
+stat_sys_form(badlength);
+stat_sys_form(badauth);
+stat_sys_form(declined);
+stat_sys_form(limitrejected);
+stat_sys_form(kodsent);
+#undef stat_sys_form
+
+extern uptime_t stat_total_stattime(void);
+extern uptime_t stat_stattime(void);
+
+extern void increment_restricted(void);
+extern uptime_t stat_use_stattime(void);
+extern void set_use_stattime(uptime_t stattime);
+extern uptime_t	use_stattime;		/* time since usestats reset */
+
 extern	void	poll_update	(struct peer *, uint8_t);
 
 extern	void	clock_filter	(struct peer *, double, double, double);
@@ -173,23 +213,6 @@ extern	void	set_sys_tick_precision(double);
 extern	void	proto_config	(int, unsigned long, double);
 extern	void	proto_clr_stats (void);
 
-extern uptime_t stat_stattime(void);
-extern uint64_t stat_received(void);
-extern uint64_t stat_processed(void);
-extern uint64_t stat_restricted(void);
-extern void increment_restricted(void);
-extern uint64_t stat_newversion(void);
-extern uint64_t stat_oldversion(void);
-extern uint64_t stat_badlength(void);
-extern uint64_t stat_badauth(void);
-extern uint64_t stat_declined(void);
-extern uint64_t stat_limitrejected(void);
-extern uint64_t stat_kodsent(void);
-extern uptime_t stat_use_stattime(void);
-extern void set_use_stattime(uptime_t stattime);
-
-
-
 /* ntp_restrict.c */
 extern	void	init_restrict	(void);
 extern	unsigned short	restrictions	(sockaddr_u *);
@@ -209,6 +232,7 @@ extern	uptime_t	orphwait;		/* orphan wait time */
 
 /* ntp_util.c */
 extern	void	init_util	(void);
+extern	void 	write_pidfile	(const char *, pid_t);
 extern	void	write_stats	(void);
 extern	void	stats_config	(int, const char *);
 extern	void	record_peer_stats (struct peer *, int);
@@ -217,11 +241,12 @@ extern	void	record_loop_stats (double, double, double, double, int);
 extern	void	record_clock_stats (struct peer *, const char *);
 extern	int	mprintf_clock_stats(struct peer *, const char *, ...)
 			NTP_PRINTF(2, 3);
-extern	void	record_raw_stats (struct peer *,
-				  int leap, int version, int mode, int stratum,
-				  int ppoll, int precision, double root_delay,
-				  double root_dispersion, refid_t refid,
-				  unsigned int outcount);
+extern	void	record_raw_stats (
+  struct peer *peer,
+  struct recvbuf *rbufp,
+  unsigned int flag,
+  unsigned int outcount);
+
 extern void record_ref_stats(
     const struct peer *peer,
     int     n,              /* Number of samples */
@@ -420,7 +445,21 @@ extern struct restriction_data rstrct;
 
 #ifdef ENABLE_MSSNTP
 /* ntp_signd.c */
-extern void send_via_ntp_signd(struct recvbuf *, keyid_t, int, void *);
+extern void send_via_ntp_signd(struct recvbuf *, void *);
+
+struct mssntp_counters {
+  uint64_t serves;		/* packets to send_via_ntp_signd */
+  uint64_t serves_no;		/* can't contact samba */
+  uint64_t serves_err;		/* troubles talking to samba */
+  uint64_t serves_good;
+  l_fp     serves_good_wall;
+  l_fp     serves_good_slowest;
+  uint64_t serves_bad;		/* samba said error */
+  l_fp     serves_bad_wall;
+  l_fp     serves_bad_slowest;
+};
+
+extern struct mssntp_counters mssntp_cnt, old_mssntp_cnt;
 #endif
 
 /* ntp_timer.c */
