@@ -14,7 +14,7 @@
 
 #include "pymodule-mac.h"
 
-/* Don't include Python.h */
+// Don't include Python.h
 
 #define OPENSSL_SUPPRESS_DEPRECATED 1
 #include <openssl/evp.h>
@@ -25,23 +25,21 @@
 #ifndef EVP_MD_CTX_new
 #define EVP_MD_CTX_new() EVP_MD_CTX_create()
 #endif
-#ifndef EVP_MD_CTX_reset
-#define EVP_MD_CTX_reset(ctx) EVP_MD_CTX_init(ctx)
-#endif
 
-/* Needed on OpenSSL < 1.1.0 */
+// Needed on OpenSSL < 1.1.0
 static void init_ssl(void) {
 	static bool init_done = false;
-	if (init_done)
+	if (init_done) {
 		return;
+        }
 	init_done = true;
 	OpenSSL_add_all_ciphers();
 	OpenSSL_add_all_digests();
 }
 
 /* xx = ntp.ntpc.checkname(name)
- * returns false if algorithm name is invalid. */
-
+ * returns false if algorithm name is invalid.
+ */
 int do_checkname(const char *name)
 {
 	char upcase[100];
@@ -74,11 +72,11 @@ int do_checkname(const char *name)
 }
 
 
-/* mac = ntp.ntpc.mac(data, key, name) */
+// mac = ntp.ntpc.mac(data, key, name)
 
 #if EVP_MAX_MD_SIZE > MAX_MAC_LENGTH
 #error "MAX_MAC_LENGTH isn't big enough"
-/* FIXME: Does this cover CMAC ?? */
+// FIXME: Does this cover CMAC ??
 #endif
 
 void do_mac(char *name,
@@ -103,11 +101,11 @@ void do_mac(char *name,
 
         digest = EVP_get_digestbyname(upcase);
 	if (NULL != digest) {
-		/* Old digest case, MD5, SHA1 */
+		// Old digest case, MD5, SHA1
 		unsigned int maclenint;
-		if (NULL == digest_ctx)
+		if (NULL == digest_ctx) {
 			digest_ctx = EVP_MD_CTX_new();
-		EVP_MD_CTX_reset(digest_ctx);
+                }
 		if (!EVP_DigestInit_ex(digest_ctx, digest, NULL)) {
 			*maclen = 0;
 			return;
@@ -115,8 +113,9 @@ void do_mac(char *name,
 		EVP_DigestUpdate(digest_ctx, key, keylen);
 		EVP_DigestUpdate(digest_ctx, data, (unsigned int)datalen);
 		EVP_DigestFinal_ex(digest_ctx, mac, &maclenint);
-		if (MAX_MAC_LENGTH < maclenint)
+		if (MAX_MAC_LENGTH < maclenint) {
 			maclenint = MAX_MAC_LENGTH;
+                }
 		*maclen = maclenint;
 		return;
 	}
@@ -133,24 +132,36 @@ void do_mac(char *name,
 	}
 	cipherlen = EVP_CIPHER_key_length(cipher);
 	if (cipherlen < keylen) {
-		keylen = cipherlen;		/* truncate */
+		keylen = cipherlen;		// truncate
 	} else if (cipherlen > keylen) {
 		memcpy(newkey, key, keylen);
-		while (cipherlen > keylen)
-			key[keylen++] = 0;	/* pad with 0s */
+		while (cipherlen > keylen) {
+			key[keylen++] = 0;	// pad with 0s
+                }
 		key = newkey;
 	}
-	if (NULL == cmac_ctx)
+        /* Coverity CID 462307, 2023 June 11
+         * CMAC API is undocumented and deprecated in OpenSSL 3.
+         * See libntp/macencrypt.c
+         */
+	if (NULL == cmac_ctx) {
 		cmac_ctx = CMAC_CTX_new();
+        }
         if (!CMAC_Init(cmac_ctx, key, keylen, cipher, NULL)) {
-                /* Shouldn't happen.  Does if wrong key_size. */
+                // Shouldn't happen.  Does if wrong key_size.
 		*maclen = 0;
 		return;
         }
-        CMAC_Update(cmac_ctx, data, (unsigned int)datalen);
-        CMAC_Final(cmac_ctx, mac, maclen);
-        if (MAX_MAC_LENGTH < *maclen)
+        if (!CMAC_Update(cmac_ctx, data, (unsigned int)datalen)) {
+                *maclen = 0;
+                return;
+        }
+        if (!CMAC_Final(cmac_ctx, mac, maclen)) {
+                *maclen = 0;
+                return;
+        }
+        if (MAX_MAC_LENGTH < *maclen) {
                 *maclen = MAX_MAC_LENGTH;
+        }
 	return;
 }
-
