@@ -109,17 +109,6 @@ ntpc_lfptofloat(PyObject *self, PyObject *args)
 	return Py_BuildValue("d", tt.tv_sec + tt.tv_nsec * S_PER_NS);
 }
 
-static PyObject *
-ntpc_set_tod(PyObject *self, PyObject *args)
-{
-	struct timespec ts;
-
-	UNUSED_ARG(self);
-	if (!PyArg_ParseTuple(args, "ii", &ts.tv_sec, &ts.tv_nsec))
-		return NULL;
-	return Py_BuildValue("d", ntp_set_tod(&ts));
-}
-
 static PyObject *
 ntpc_adj_systime(PyObject *self, PyObject *args)
 {
@@ -147,7 +136,7 @@ ntpc_step_systime(PyObject *self, PyObject *args)
 	if (!PyArg_ParseTuple(args, "d", &adjustment))
 		return NULL;
 	full_adjustment = adjustment;
-	return Py_BuildValue("d", step_systime(full_adjustment, ntp_set_tod));
+	return Py_BuildValue("d", step_systime(full_adjustment));
 }
 
 /* --------------------------------------------------------------- */
@@ -209,11 +198,11 @@ ntpc_mac(PyObject *self, PyObject *args)
 
 	do_mac(name,
 		data, datalen,
-      		key, keylen,
- 	        mac, &maclen);
+		key, keylen,
+		mac, &maclen);
 
 	if (maclen == 0)
-                Py_RETURN_NONE;
+		Py_RETURN_NONE;
 	
 #if PY_MAJOR_VERSION >= 3
 	return Py_BuildValue("y#", &mac, maclen);
@@ -225,25 +214,23 @@ ntpc_mac(PyObject *self, PyObject *args)
 /* List of functions defined in the module */
 
 static PyMethodDef ntpc_methods[] = {
-    {"setprogname",    ntpc_setprogname,  	METH_VARARGS,
-     PyDoc_STR("Set program name for logging purposes.")},
-    {"statustoa",      	ntpc_statustoa,  	METH_VARARGS,
-     PyDoc_STR("Status string display from peer status word.")},
-    {"prettydate",     	ntpc_prettydate,  	METH_VARARGS,
-     PyDoc_STR("Convert a time stamp to something readable.")},
-    {"lfptofloat",     	ntpc_lfptofloat,  	METH_VARARGS,
-     PyDoc_STR("NTP l_fp to Python-style float time.")},
-    {"set_tod",     	ntpc_set_tod,   	METH_VARARGS,
-     PyDoc_STR("Set time to nanosecond precision.")},
-    {"adj_systime",    	ntpc_adj_systime,   	METH_VARARGS,
-     PyDoc_STR("Adjust system time by slewing.")},
-    {"step_systime",    ntpc_step_systime,   	METH_VARARGS,
-     PyDoc_STR("Adjust system time by stepping.")},
-    {"checkname",       ntpc_checkname,   	METH_VARARGS,
-     PyDoc_STR("Check if name is a valid algorithm name")},
-    {"mac",             ntpc_mac,   		METH_VARARGS,
-     PyDoc_STR("Compute HMAC or CMAC from data, key, and algorithm name")},
-    {NULL,		NULL, 0, NULL}		/* sentinel */
+	{"setprogname",		ntpc_setprogname,	METH_VARARGS,
+	 PyDoc_STR("Set program name for logging purposes.")},
+	{"statustoa",		ntpc_statustoa,		METH_VARARGS,
+	 PyDoc_STR("Status string display from peer status word.")},
+	{"prettydate",		ntpc_prettydate,	METH_VARARGS,
+	 PyDoc_STR("Convert a time stamp to something readable.")},
+	{"lfptofloat",		ntpc_lfptofloat,	METH_VARARGS,
+	 PyDoc_STR("NTP l_fp to Python-style float time.")},
+	{"adj_systime",		ntpc_adj_systime,	METH_VARARGS,
+	 PyDoc_STR("Adjust system time by slewing.")},
+	{"step_systime",	ntpc_step_systime,	METH_VARARGS,
+	 PyDoc_STR("Adjust system time by stepping.")},
+	{"checkname",		ntpc_checkname,		METH_VARARGS,
+	 PyDoc_STR("Check if name is a valid algorithm name")},
+	{"mac",			ntpc_mac,		METH_VARARGS,
+	 PyDoc_STR("Compute HMAC or CMAC from data, key, and algorithm name")},
+	{NULL,			NULL, 0, NULL}		/* sentinel */
 };
 
 PyDoc_STRVAR(module_doc,
@@ -262,8 +249,8 @@ NTPSEC_PY_MODULE_INIT(ntpc)
 	/* Create the module and add the functions */
 	NTPSEC_PY_MODULE_DEF(m, "ntpc", module_doc, ntpc_methods)
 
-	    /* for statustoa() */
-	    PyModule_AddIntConstant(m, "TYPE_SYS", TYPE_SYS);
+	/* for statustoa() */
+	PyModule_AddIntConstant(m, "TYPE_SYS", TYPE_SYS);
 	PyModule_AddIntConstant(m, "TYPE_PEER", TYPE_PEER);
 	PyModule_AddIntConstant(m, "TYPE_CLOCK", TYPE_CLOCK);
 
