@@ -76,14 +76,14 @@ def checkname(name):
 def mac(data, key, name):
     """Compute HMAC or CMAC from data, key, and algorithm name."""
     resultlen = ctypes.c_size_t()
-    result = (ctypes.c_char * 64)()
+    result = (ctypes.c_ubyte * 64)()
     result.value = b'\0' * 64
     _ntpc.do_mac.restype = None
     _ntpc.do_mac(ntp.poly.polybytes(name),
                  ntp.poly.polybytes(data), len(data),
                  ntp.poly.polybytes(key), len(key),
                  ctypes.byref(result), ctypes.byref(resultlen))
-    return result.value
+    return ntp.poly.polybytes(bytearray(result)[:min(resultlen.value, 20)])
 
 
 def setprogname(in_string):
@@ -147,11 +147,6 @@ _statustoa = _ntpc.statustoa
 _statustoa.restype = ctypes.c_char_p
 _statustoa.argtypes = [ctypes.c_int, ctypes.c_int]
 
-# Set time to nanosecond precision.
-set_tod = _ntpc.ntpc_set_tod
-set_tod.restype = ctypes.c_int
-set_tod.argtypes = [ctypes.c_int, ctypes.c_int]
-
 # Adjust system time by slewing.
 adj_systime = _ntpc.ntpc_adj_systime
 adj_systime.restype = ctypes.c_bool
