@@ -112,6 +112,14 @@ def stdversion():
     return "ntpsec-%s" % "@NTPSEC_VERSION_EXTENDED@"
 
 
+def stdversioncheck(foreign):
+    "Print a warning to stderr if module and foreign versions do not match."
+    if stdversion() != foreign:
+        sys.stderr.write("Module/Binary version mismatch\n")
+        sys.stderr.write("Binary: %s\n" % foreign)
+        sys.stderr.write("Module: %s\n" % ntp.util.stdversion())
+
+
 def rfc3339(t):
     "RFC 3339 string from Unix time, including fractional second."
     rep = time.strftime("%Y-%m-%dT%H:%M:%S", time.gmtime(t))
@@ -638,7 +646,7 @@ def canonicalize_dns(inhost, family=socket.AF_UNSPEC):
     if resname is not None:
         return resname
     # Catch garbaged hostnames in corrupted Mode 6 responses
-    m = re.match("([:.[\]]|\w)*", inhost)
+    m = re.match(r"([:.[\]]|\w)*", inhost)
     if not m:
         raise TypeError
     (hostname, portsuffix) = portsplit(inhost)
@@ -1395,7 +1403,7 @@ class IfstatsSummary:
         # FIXME, a brutal and slow way to check for invalid chars..
         # maybe just strip non-printing chars?
         for c in s:
-            if not c.isalnum() and c not in "/.:[] \%\n":
+            if not c.isalnum() and c not in "/.:[] %\n":
                 return ''
         return s
 
